@@ -5,6 +5,9 @@ import string
 import os
 
 class KnowledgeBase:
+    """
+    The KnowledgeBase class is used to create, update, and delete knowledge bases. It can also be used to directly query a knowledge base.
+    """
     def __init__(self, title: str, supp_id: str = None, description: str = None, kb_id: str = None):
         self.title = title
         self.supp_id = supp_id
@@ -49,11 +52,15 @@ class KnowledgeBase:
             documents[document['id']] = kb_document
         return documents
 
-    def query(self, query: str, top_k: int = 10):
+    def query(self, query: str, retriever_top_k: int = 100, reranker_top_k: int = 5):
+        """
+        directly query a knowledge base
+        """
         url = BASE_URL + f'knowledge_bases/{self.kb_id}/query'
         payload = {
             'query': query,
-            'top_k': top_k,
+            'retriever_top_k': retriever_top_k,
+            'reranker_top_k': reranker_top_k,
         }
         resp = _format_http_response(requests.post(url, headers=get_headers(), json=payload))
         return resp["body"]
@@ -65,6 +72,9 @@ class KnowledgeBase:
 
 
 class KnowledgeBaseDocument:
+    """
+    The KnowledgeBaseDocument class is used to create and delete documents in a knowledge base.
+    """
     def __init__(self, kb_id: str, content: str, title: str = None, link_to_source: str = None, supp_id: str = None, description: str = None, doc_id: str = None):
         self.kb_id = kb_id
         self.content = content # content is a string
@@ -111,14 +121,18 @@ def get_knowledge_bases():
         knowledge_bases[knowledge_base['id']] = kb
     return knowledge_bases
 
-# create_knowledge_base() is a convenience function that creates a KnowledgeBase object and then calls its create() method
 def create_knowledge_base(title: str, supp_id: str = None, description: str = None):
+    """
+    create_knowledge_base() is a convenience function that creates a KnowledgeBase object and then calls its create() method
+    """
     kb = KnowledgeBase(title, supp_id, description)
     resp = kb.create()
     return kb
 
-# get_knowledge_base() is a convenience function that returns a KnowledgeBase object for an existing knowledge base, given its title
 def get_knowledge_base(title: str):
+    """
+    get_knowledge_base() is a convenience function that returns a KnowledgeBase object for an existing knowledge base, given its title
+    """
     knowledge_bases = get_knowledge_bases()
     # create knowledge base name to id map - knowledge_bases is a dict of knowledge base objects keyed on knowledge_base_id
     kb_from_title = {}
@@ -136,8 +150,10 @@ def get_knowledge_base(title: str):
     else:
         raise Exception('Knowledge base title not found: ' + title)
 
-# list_knowledge_bases() is a convenience function that returns a dictionary of all KnowledgeBase objects for an account
 def list_knowledge_bases(verbose=True):
+    """
+    list_knowledge_bases() is a convenience function that returns a dictionary of all KnowledgeBase objects for an account
+    """
     knowledge_bases = get_knowledge_bases()
     if verbose:
         print ("\nKnowledge bases:")
@@ -145,8 +161,10 @@ def list_knowledge_bases(verbose=True):
             print (f"id: {kb_obj.kb_id}\ntitle: {kb_obj.title}\n")
     return knowledge_bases
 
-# list_documents_in_kb() is a convenience function that returns a dictionary of KnowledgeBaseDocument objects for an existing knowledge base, given its title
-def list_documents_in_kb(kb_title: str, verbose=False):
+def list_documents_in_kb(kb_title: str, verbose=True):
+    """
+    list_documents_in_kb() is a convenience function that returns a dictionary of KnowledgeBaseDocument objects for an existing knowledge base, given its title
+    """
     kb = get_knowledge_base(kb_title)
     documents = kb.get_documents()
     if verbose:
@@ -155,8 +173,10 @@ def list_documents_in_kb(kb_title: str, verbose=False):
             print (f"title: {document_obj.title}\ncontent: {document_obj.content[:100]}\n\n")
     return documents
 
-# add a file to a knowledge base
 def add_file_to_kb(kb_title: str, file_path: str, file_type: str = None):
+    """
+    add a file to a knowledge base - currently only supports .txt files
+    """
     kb = get_knowledge_base(kb_title)
     if file_type is None:
         file_type = file_path.split(".")[-1]
@@ -172,8 +192,10 @@ def add_file_to_kb(kb_title: str, file_path: str, file_type: str = None):
     title = ''.join(random.choices(string.ascii_uppercase + string.digits, k=10))
     kb.add_document(content=content, title=title)
 
-# add all the supported files in a directory to a knowledge base
 def add_directory_to_kb(kb_title: str, directory_path: str, verbose=False):
+    """
+    add all the supported files in a directory to a knowledge base
+    """
     # TODO: add support for other file types
     # TODO: make sure this works for all different kinds of subdirectory structures - currently it's only been tested for one level of subdirectories
     # get all the txt files in the directory, and all subdirectories
